Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(699)

Unified Diff: media/video/video_decode_accelerator.h

Issue 6901036: Update VideoDecode PPAPI structs to be consistent with media structures, part 1 (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 9 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/video/video_decode_accelerator.h
diff --git a/media/video/video_decode_accelerator.h b/media/video/video_decode_accelerator.h
index be799c1186cd763fe4938dedda68bbc4511cb17a..b69541ae75ad118fc8d819ec06f81b63ddae9ea6 100644
--- a/media/video/video_decode_accelerator.h
+++ b/media/video/video_decode_accelerator.h
@@ -260,14 +260,13 @@ class VideoDecodeAccelerator {
struct {
uint32 context_id; // GLES context id.
uint32 texture_id; // GLES texture id.
- };
+ } gles2_texture;
void* sysmem; // Simply a pointer to system memory.
};
virtual ~PictureBuffer();
virtual int32 GetId() = 0;
virtual gfx::Size GetSize() = 0;
- virtual const std::vector<uint32>& GetColorFormat() = 0;
virtual MemoryType GetMemoryType() = 0;
virtual std::vector<DataPlaneHandle>& GetPlaneHandles() = 0;
};
@@ -302,8 +301,8 @@ class VideoDecodeAccelerator {
// the picture buffer size it has provided to the decoder. Thus, there is
// no function to query the buffer size from this class.
- // Returns the picture buffer where this picture is contained.
- virtual PictureBuffer* picture_buffer() = 0;
+ // Returns the id of the picture buffer where this picture is contained.
+ virtual int32 GetId() = 0;
// Returns the decoded size of the decoded picture in pixels.
virtual gfx::Size GetDecodedSize() const = 0;
@@ -328,10 +327,10 @@ class VideoDecodeAccelerator {
const std::vector<uint32>& buffer_properties) = 0;
// Callback to dismiss picture buffer that was assigned earlier.
- virtual void DismissPictureBuffer(PictureBuffer* picture_buffer) = 0;
+ virtual void DismissPictureBuffer(int32 picture_buffer_id) = 0;
// Callback to deliver decoded pictures ready to be displayed.
- virtual void PictureReady(Picture* picture) = 0;
+ virtual void PictureReady(Picture& picture) = 0;
scherkus (not reviewing) 2011/04/26 22:36:34 why ref versus pointer? if ref we usually go with
vrk (LEFT CHROMIUM) 2011/04/27 00:40:33 I believe the only reason the parameter is a point
// Callback to notify that decoder has decoded end of stream marker and has
// outputted all displayable pictures.
@@ -387,8 +386,8 @@ class VideoDecodeAccelerator {
// picture buffers it can write the output to.
//
// Parameters:
- // |picture_buffer| points to the picture buffer that is to be reused.
- virtual void ReusePictureBuffer(PictureBuffer* picture_buffer) = 0;
+ // |picture_buffer_id| id of the picture buffer that is to be reused.
+ virtual void ReusePictureBuffer(uint32 picture_buffer_id) = 0;
// Flushes the decoder. Flushing will result in output of the
// pictures and buffers held inside the decoder and returning of bitstream
« no previous file with comments | « media/video/picture.cc ('k') | ppapi/c/dev/pp_video_dev.h » ('j') | ppapi/c/dev/pp_video_dev.h » ('J')

Powered by Google App Engine
This is Rietveld 408576698